package javax.swing.plaf.nimbus;

import javax.swing.JComponent;
import java.awt.Graphics2D;
import java.awt.Color;
import java.awt.geom.Ellipse2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.geom.Rectangle2D;
import java.awt.geom.Path2D;

final class MenuPainter extends AbstractRegionPainter
{
    static final int BACKGROUND_DISABLED = 1;
    static final int BACKGROUND_ENABLED = 2;
    static final int BACKGROUND_ENABLED_SELECTED = 3;
    static final int ARROWICON_DISABLED = 4;
    static final int ARROWICON_ENABLED = 5;
    static final int ARROWICON_ENABLED_SELECTED = 6;
    private int state;
    private AbstractRegionPainter.PaintContext ctx;
    private Path2D path;
    private Rectangle2D rect;
    private RoundRectangle2D roundRect;
    private Ellipse2D ellipse;
    private Color color1;
    private Color color2;
    private Color color3;
    private Color color4;
    private Object[] componentColors;
    
    public MenuPainter(AbstractRegionPainter.PaintContext ctx, int state) {
        this.path = new Path2D.Float();
        this.rect = new Rectangle2D.Float(0.0f, 0.0f, 0.0f, 0.0f);
        this.roundRect = new RoundRectangle2D.Float(0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f);
        this.ellipse = new Ellipse2D.Float(0.0f, 0.0f, 0.0f, 0.0f);
        this.color1 = this.decodeColor("nimbusSelection", 0.0f, 0.0f, 0.0f, 0);
        this.color2 = this.decodeColor("nimbusBlueGrey", 0.0f, -0.08983666f, -0.17647058f, 0);
        this.color3 = this.decodeColor("nimbusBlueGrey", 0.055555582f, -0.09663743f, -0.4627451f, 0);
        this.color4 = new Color(255, 255, 255, 255);
        this.state = state;
        this.ctx = ctx;
    }
    
    @Override
    protected void doPaint(Graphics2D graphics2D, JComponent component, int n, int n2, Object[] componentColors) {
        this.componentColors = componentColors;
        switch (this.state) {
            case 3: {
                this.paintBackgroundEnabledAndSelected(graphics2D);
                break;
            }
            case 4: {
                this.paintarrowIconDisabled(graphics2D);
                break;
            }
            case 5: {
                this.paintarrowIconEnabled(graphics2D);
                break;
            }
            case 6: {
                this.paintarrowIconEnabledAndSelected(graphics2D);
                break;
            }
        }
    }
    
    @Override
    protected final AbstractRegionPainter.PaintContext getPaintContext() {
        return this.ctx;
    }
    
    private void paintBackgroundEnabledAndSelected(Graphics2D graphics2D) {
        this.rect = this.decodeRect1();
        graphics2D.setPaint(this.color1);
        graphics2D.fill(this.rect);
    }
    
    private void paintarrowIconDisabled(Graphics2D graphics2D) {
        this.path = this.decodePath1();
        graphics2D.setPaint(this.color2);
        graphics2D.fill(this.path);
    }
    
    private void paintarrowIconEnabled(Graphics2D graphics2D) {
        this.path = this.decodePath1();
        graphics2D.setPaint(this.color3);
        graphics2D.fill(this.path);
    }
    
    private void paintarrowIconEnabledAndSelected(Graphics2D graphics2D) {
        this.path = this.decodePath2();
        graphics2D.setPaint(this.color4);
        graphics2D.fill(this.path);
    }
    
    private Rectangle2D decodeRect1() {
        this.rect.setRect((double)this.decodeX(1.0f), (double)this.decodeY(1.0f), (double)(this.decodeX(2.0f) - this.decodeX(1.0f)), (double)(this.decodeY(2.0f) - this.decodeY(1.0f)));
        return this.rect;
    }
    
    private Path2D decodePath1() {
        this.path.reset();
        this.path.moveTo((double)this.decodeX(0.0f), (double)this.decodeY(0.2f));
        this.path.lineTo((double)this.decodeX(2.7512195f), (double)this.decodeY(2.102439f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(3.0f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(0.2f));
        this.path.closePath();
        return this.path;
    }
    
    private Path2D decodePath2() {
        this.path.reset();
        this.path.moveTo((double)this.decodeX(0.0f), (double)this.decodeY(1.0f));
        this.path.lineTo((double)this.decodeX(1.9529617f), (double)this.decodeY(1.5625f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(3.0f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(1.0f));
        this.path.closePath();
        return this.path;
    }
}
